#!/bin/sh
##
## Execute proper command to install an init script
##

### BEGIN INIT INFO
# Provides: dsm_installscript.sh
# Required-Start: $local_fs $remote_fs $syslog
# Required-Stop: $local_fs $remote_fs $syslog
# Default-Start: 3 5 
### END INIT INFO

InstallInitScript()
{
    INIT_SCRIPT_NAME="${1}"
    # sanity check, was a non-NULL init script name passed
    if [ -z "${INIT_SCRIPT_NAME}" ];
    then
        logger -i -t dsm_installscript.sh \
	The init script name passed in,\
	is NULL. This package cannot be installed. 
        exit 2
    fi

    # sanity check, was a valid init script name passed
    if [ ! -e /etc/init.d/"${INIT_SCRIPT_NAME}" ];
    then
        logger -i -t dsm_installscript.sh \
	The init script name passed in, does not exist.\
	This package cannot be installed.\
	Verify that /etc/init.d/${INIT_SCRIPT_NAME} exists.
        exit 3
    fi

    # check for lsb install (for SUSE)
    if [ -x /usr/lib/lsb/install_initd ];
    then
        # this is an lsb install
        /usr/lib/lsb/install_initd /etc/init.d/${INIT_SCRIPT_NAME}
    elif [ -x /sbin/chkconfig ];
    then
        # this is a Red Hat type install
        /sbin/chkconfig --add ${INIT_SCRIPT_NAME}
	# added for ubuntu support
	elif [ -x /usr/sbin/update-rc.d ];
	then
		update-rc.d $INIT_SCRIPT_NAME defaults >/dev/null 2>&1
    else
        # this is seriously broken
        logger -i -t dsm_installscript.sh \
	The init script installers: /usr/lib/lsb/install_initd \
	or /sbin/chkconfig could not be found or do not have \
	executable permission.\
	The /etc/init.d/${INIT_SCRIPT_NAME} cannot be installed.
        exit 1
    fi

    return 0
}

UninstallInitScript()
{
    INIT_SCRIPT_NAME="${1}"
    # sanity check, was a non-NULL init script name passed
    if [ -z "${INIT_SCRIPT_NAME}" ];
    then
        logger -i -t dsm_installscript.sh \
	The init script name passed in, is NULL.\
	This package cannot be installed.
        exit 2
    fi

    # sanity check, was a valid init script name passed
    if [ ! -e /etc/init.d/"${INIT_SCRIPT_NAME}" ];
    then
        logger -i -t dsm_installscript.sh \
	The init script name passed in, does not exist.\
	This package cannot be installed.\
	Verify that /etc/init.d/${INIT_SCRIPT_NAME} exists.
        exit 3
    fi

    # check for lsb install (for SUSE)
    if [ -x /usr/lib/lsb/remove_initd ];
    then
        # this is an lsb install
        /usr/lib/lsb/remove_initd /etc/init.d/${INIT_SCRIPT_NAME}
    elif [ -x /sbin/chkconfig ];
    then
        # this is a Red Hat type install
	echo "/sbin/chkconfig --del ${INIT_SCRIPT_NAME}"
        /sbin/chkconfig --del ${INIT_SCRIPT_NAME}
	# added for ubuntu support
	elif [ -x /usr/sbin/update-rc.d ];
	then
		update-rc.d -f $INIT_SCRIPT_NAME remove >/dev/null 2>&1
    else
        # this is seriously broken
        logger -i -t dsm_installscript.sh \
	The init script uninstallers: /usr/lib/lsb/uninstall_initd \
	or /sbin/chkconfig could not be found or do not have \
	executable permission. 
	The /etc/init.d/${INIT_SCRIPT_NAME} cannot be uninstalled.
        exit 1
    fi

    return 0
}

##################################################
# Bypass biosverify setup for Embedded linux (ELI).
# ramfs file systems exist on ELI.
##################################################
#if df -a | grep ramfs >/dev/null 2>&1; then
#    exit 0
#fi

if cat /VER_INFO 2>/dev/null | grep CDU > /dev/null 2>&1; then
	exit 0
fi	

if cat /VERSION 2>/dev/null | grep DTK > /dev/null 2>&1; then
	exit 0
fi

##########################
# Init script registration
##########################

SCRIPTNAME=dsm_dupbios_restore.sh
RESTORESCRIPT=${PWD}/dsm_dupbios_restore.sh
INSTALLSCRIPT=${PWD}/dsm_installscript.sh
if [ "$1" = "remove" ];
then 
	UninstallInitScript $SCRIPTNAME
else
	install -m755 $RESTORESCRIPT /etc/init.d/
	install -m755 $INSTALLSCRIPT /etc/init.d/
	InstallInitScript $SCRIPTNAME
fi
